@@ -10,7 +10,7 @@ use XML::Simple;
 
 extends 'Tropo::RestAPI::Base';
 
-our $VERSION = 0.03;
+our $VERSION = 0.05;
 
 sub create {
     my ($self, %param) = @_;
@@ -21,8 +21,10 @@ sub create {
     
     $param{action} = 'create';
     
-    my $session_url = $self->url . 'sessions';
-    my $response    = $self->ua->get(
+    my $delim = substr( $self->url, -1 ) eq '/' ? '' : '/';
+    
+    my $session_url = $self->url . $delim . 'sessions';
+    my $response    = $self->get(
         $session_url,
         \%param,
     );
@@ -33,17 +35,22 @@ sub create {
     }
     
     if ( !$response->{success} ) {
-        $self->err( $response->{reason} );
+        $self->err( $response->{reason} . ': ' . $response->{content} );
+        return;
+    }
+    
+    if ( !$response->{content} ) {
+        $self->err( 'Tropo session launch failed!' );
+        return;
+    }
+    
+    if ( !$self->redirect && $response->{url} !~ m{ \A \Q$session_url\E }xms ) {
+        $self->err( 'Reponse from differen URL as the request was sent to!' );
         return;
     }
     
     my $data = XMLin( $response->{content} );
     
-    if ( $data->{success} ne 'true' ) {
-        $self->err( 'Tropo session launch failed!' );
-        return;
-    }
-    
     return $data;
 }
 
@@ -58,7 +65,7 @@ Tropo::RestAPI::Session - Tropo session handling
 
 =head1 VERSION
 
-version 0.05
+version 0.07
 
 =head1 SYNOPSIS
 
